@@ -21,23 +21,16 @@
 #ifdef WITH_EXTAUTH
 # include "log_extauth.h"
 #endif
-#if !defined(NO_GETOPT_LONG) && !defined(HAVE_GETOPT_LONG)
-# include "gnu-getopt.h"
+
+#ifndef HAVE_GETOPT_LONG
+# include "bsd-getopt_long.h"
 #else
-# ifdef HAVE_GETOPT_H
-#  include <getopt.h>
-# endif
+# include <getopt.h>
 #endif
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
-#ifndef WEXITSTATUS
-# define WEXITSTATUS(st) ((unsigned) (st) >> 8)
-#endif
-#ifndef WIFEXITED
-# define WIFEXITED(st) (((st) & 0xff) == 0)
-#endif
 
 #define DEFAULT_BACKLOG 42
 #define DEFAULT_BACKLOG_DATA 8
@@ -46,7 +39,11 @@
 #define MAX_GROUPS 256
 #define MAX_PASSWD_TRIES 5        /* Abort after 5 authentication failures */
 #define PASSWD_FAILURE_DELAY (3UL*1000000UL)    /* Delay after each failure */
+#define MAX_DIRSCAN_TRIES 50      /* Abort after 50 chdir failures */
+#define DIRSCAN_FAILURE_DELAY (100000UL)  /* Delay after each chdir failure */
 #define ASCII_CHUNKSIZE 65536U
+#define BANNER_MAXLINES 100
+#define MAX_SERVER_REPLY_LEN (MAXPATHLEN + (size_t) 50U)
 
 #ifndef NO_STANDALONE
 static volatile sig_atomic_t stop_server;
@@ -54,6 +51,7 @@ static const char *standalone_port = DEFAULT_FTP_PORT_S;
 static const char *standalone_ip;
 static volatile unsigned int nb_children;
 static volatile int listenfd = -1;
+static volatile int listenfd6 = -1;
 #endif
 
 struct reply {
@@ -62,7 +60,7 @@ struct reply {
 };
 
 static const char *GETOPT_OPTIONS =
-    "14Aa:bc:"
+    "0146Aa:bc:"
 #ifndef NO_STANDALONE
     "BC:"
 #endif
@@ -94,20 +92,32 @@ static const char *GETOPT_OPTIONS =
 #ifdef THROTTLING
     "t:T:"
 #endif
-    "u:U:V:wWxXzZ";
+    "u:U:V:wWxX"
+#ifdef WITH_OSX_RENDEZVOUS
+    "v:"
+#endif
+#ifdef PER_USER_LIMITS
+    "y:"
+#endif
+#ifdef WITH_TLS
+    "Y:"
+#endif    
+    "zZ";
 
 #ifndef NO_GETOPT_LONG    
 static struct option long_options[] = {
+    { "notruncate", 0, NULL, '0' },    
     { "logpid", 0, NULL, '1' },
     { "ipv4only", 0, NULL, '4' },
+    { "ipv6only", 0, NULL, '6' },    
     { "chrooteveryone", 0, NULL, 'A' },
     { "trustedgid", 1, NULL, 'a' },
     { "brokenclientscompatibility", 0, NULL, 'b' },
-    { "maxclientsnumber", 1, NULL, 'c' },
 # ifndef NO_STANDALONE
     { "daemonize", 0, NULL, 'B' },                
     { "maxclientsperip", 1, NULL, 'C' },
 # endif
+    { "maxclientsnumber", 1, NULL, 'c' },    
     { "verboselog", 0, NULL, 'd' },
     { "displaydotfiles", 0, NULL, 'D' },
     { "anonymousonly", 0, NULL, 'e' },
@@ -158,10 +168,19 @@ static struct option long_options[] = {
     { "umask", 1, NULL, 'U' },
     { "minuid", 1, NULL, 'u' },
     { "trustedip", 1, NULL, 'V' },
+#ifdef WITH_OSX_RENDEZVOUS
+    { "rendezvous", 1, NULL, 'v' },
+#endif
     { "allowuserfxp", 0, NULL, 'w' },
     { "allowanonymousfxp", 0, NULL, 'W' },
     { "prohibitdotfileswrite", 0, NULL, 'x' },
     { "prohibitdotfilesread", 0, NULL, 'X' },
+# ifdef PER_USER_LIMITS
+    { "peruserlimits", 1, NULL, 'y' },
+# endif
+# ifdef WITH_TLS
+    { "tls", 1, NULL, 'Y' },
+# endif
     { "allowdotfiles", 0, NULL, 'z' },
     { "customerproof", 0, NULL, 'Z' },
     { NULL, 0, NULL, 0 }
@@ -174,6 +193,7 @@ static const AltLogPrefixes altlogprefixes[] = {
     { "clf", ALTLOG_CLF },
     { "stats", ALTLOG_STATS },
     { "w3c", ALTLOG_W3C },
+    { "xferlog", ALTLOG_XFERLOG },
     { NULL, ALTLOG_NONE }
 };
 
@@ -181,6 +201,18 @@ static const AltLogPrefixes altlogprefixes[] = {
 # define ALTLOG_DEFAULT ALTLOG_CLF
 #endif
 
+#ifdef WITH_PRIVSEP
+# define VERSION_PRIVSEP " [privsep]"
+#else
+# define VERSION_PRIVSEP ""
+#endif
+
+#ifdef WITH_TLS
+# define VERSION_TLS " [TLS]"
+#else
+# define VERSION_TLS ""
+#endif
+
 #ifndef HAVE_SYS_FSUID_H
 static sigset_t old_sigmask;
 #endif
