@@ -28,12 +28,13 @@ GLOBAL0(signed char passive);
 GLOBAL(int datafd, -1);                    /* data connection file descriptor */
 GLOBAL0(struct sockaddr_storage ctrlconn);    /* stdin/stdout, for using the same ip number */
 GLOBAL0(signed char v6ready);                    /* IPv6 supported or not */
+GLOBAL0(signed char no_ipv4);                    /* IPv4 disabled or not */
 GLOBAL(const size_t cmdsize, MAXPATHLEN + 16U);
 GLOBAL0(char cmd[MAXPATHLEN + 32U]);        /* command line - about 30 chars for command */
 GLOBAL0(char wd[MAXPATHLEN + 1U]);            /* current working directory */
 GLOBAL0(char *root_directory);                /* root directory, for chroot'd environments */
 GLOBAL0(signed char loggedin);                    /* != 0 if the user if logged in */
-GLOBAL0(char account[42]);                /* user login */
+GLOBAL0(char account[MAX_USER_LENGTH + 1U]);      /* user login */
 GLOBAL0(char *renamefrom);
 GLOBAL0(unsigned short int serverport);    /* local server port */
 GLOBAL0(signed char userchroot);                /* don't chroot() by default for regular users */
@@ -75,6 +76,7 @@ GLOBAL0(int replycode);
 GLOBAL0(signed char force_ls_a);
 GLOBAL0(struct sockaddr_storage peer);
 GLOBAL0(struct sockaddr_storage force_passive_ip);
+GLOBAL0(const char *force_passive_ip_s);
 GLOBAL0(unsigned short int peerdataport);
 GLOBAL0(double maxload);
 GLOBAL(unsigned int maxusers, DEFAULT_MAX_USERS);
@@ -115,6 +117,7 @@ GLOBAL0(signed char daemonize);
 GLOBAL0(int shm_id);
 GLOBAL0(FTPWhoEntry *shm_data);
 GLOBAL0(FTPWhoEntry *shm_data_cur);
+GLOBAL0(char *scoreboardfile);
 #endif
 
 #if defined(WITH_UPLOAD_SCRIPT)
@@ -125,6 +128,7 @@ GLOBAL(int upload_pipe_lock, -1);
 
 GLOBAL0(signed char create_home);
 GLOBAL0(signed char disallow_rename);
+GLOBAL0(signed char no_truncate);
 
 GLOBAL0(size_t page_size);
 GLOBAL0(size_t map_size);
@@ -147,6 +151,11 @@ GLOBAL(unsigned long long user_quota_files, ULONG_LONG_MAX);
                      "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
 GLOBAL(const char *months[12], { MONTHS_NAMES });
 
+#ifdef WITH_ALTLOG
+# define WEEK_DAYS_NAMES "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
+GLOBAL(const char *week_days[7], { WEEK_DAYS_NAMES });
+#endif
+
 GLOBAL0(AuthResult authresult);
 GLOBAL0(time_t session_start_time);
 
@@ -156,4 +165,10 @@ GLOBAL(const char *pid_file, PID_FILE);
 
 GLOBAL0(signed char be_customer_proof);
 
+#ifdef WITH_TLS
+GLOBAL0(signed char enforce_tls_auth);
+#endif
+
+GLOBAL0(char *atomic_prefix);
+
 #endif
