@@ -26,9 +26,7 @@ void pw_puredb_parse(const char * const file)
 
 void pw_puredb_exit(void)
 {
-    if (pdb_filename != NULL) {
-        free(pdb_filename);
-    }
+    free(pdb_filename);
 }
 
 /*
@@ -127,6 +125,7 @@ static int access_ip_match(const struct sockaddr_storage * const sa,
                 ip = (ip_raw[0] << 24) | (ip_raw[1] << 16) |
                     (ip_raw[2] << 8) | ip_raw[3];
                 netbits = 32U;
+                freeaddrinfo(res);
                 goto ipcheck_ipdone;
             }
         }
@@ -281,6 +280,11 @@ static int pw_puredb_parseline(char *line, const char * const pwd,
     if ((line = my_strtok2(NULL, *PW_LINE_SEP)) == NULL) {   /* max cnx */
         return 0;
     }
+#ifdef PER_USER_LIMITS    
+    if (*line != 0) {
+    result->per_user_max = (unsigned int) strtoull(line, NULL, 10);
+    }
+#endif
     if ((line = my_strtok2(NULL, *PW_LINE_SEP)) == NULL) {   /* files quota */
         return 0;
     }
