@@ -173,14 +173,13 @@
 #define MSG_WELCOME_TO "Herzlich willkommen auf"
 #define MSG_MAX_USERS "%lu Benutzer (maximal) sind schon eingeloggt, sorry."
 #define MSG_NB_USERS "Sie sind Benutzer %d von %d erlaubten."
-#define MSG_WELCOME_TIME "Lokale Zeit: %02d:%02d, Last: %3.2f. Serverport: %u."
+#define MSG_WELCOME_TIME "Lokale Zeit: %02d:%02d. Serverport: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Nur anonymes FTP erlaubt."
 #define MSG_RATIOS_EVERYONE "RATIOS SIND FR JEDEN AKTIVIERT:"
 #define MSG_RATIOS_ANONYMOUS "ANONYME NUTZER UNTERLIEGEN EINER UPLOAD/DOWNLOAD-QUOTE:"
 #define MSG_RATIOS_RULE "um %u Mb herunterzuladen, mssen %u Mb hochgeladen werden."
 #define MSG_INFO_IDLE_M "Sie werden nach %lu Minuten Inaktivitt getrennt."
 #define MSG_INFO_IDLE_S "Sie werden nach %lu Sekunden Inaktivitt getrennt."
-#define MSG_INFO_CPU_TIME "Logout - Prozessorzeit: %ld.%03ld Sekunden."
 #define MSG_CANT_READ_FILE "konnte [%s] nicht lesen."
 #define MSG_LS_TRUNCATED "Anzeige auf %u Eintrge beschrnkt."
 #define MSG_LS_SUCCESS "%u Eintrge gesamt."
@@ -215,3 +214,7 @@
 #define MSG_ALIASES_LIST "Folgende Aliase stehen zur Verfgung:"
 #define MSG_PERUSER_MAX "Mehr als %lu Verbindungen vom selben Benutzer sind nicht erlaubt"
 #define MSG_IPV6_OK "Auf diesem Server sind auch IPv6-Verbindungen willkommen"
+#define MSG_TLS_INFO "SSL/TLS: %s Verschlsselung mit %s, %d bit Schlssellnge"
+#define MSG_TLS_WEAK "SSL/TLS: Verschlsselung zu schwach"
+#define MSG_TLS_NEEDED "Sorry, unverschlsselte Sitzungen werden auf diesem Server nicht akzeptiert.\n" \
+    "Bitte verbinden Sie sich mittels SSL/TLS-Verschlsselung"
