@@ -1,6 +1,6 @@
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "No se han podido alternar capacidades"
-#define MSG_CLIENT_CLOSED_CNX "Cliente cerr la conexin"
+#define MSG_CLIENT_CLOSED_CNX "El cliente cerr la conexin"
 #define MSG_CLIENT_READ_ERR "Error de lectura del cliente"
 #define MSG_CANT_OPEN_CNX "No se puede abrir conexin"
 #define MSG_CANT_CREATE_DATA_SOCKET "No se puede crear el socket de datos"
@@ -17,9 +17,9 @@
 #define MSG_IS_YOUR_CURRENT_LOCATION "es tu localizacin actual"
 #define MSG_NOT_LOGGED_IN "No ests dentro del sistema"
 #define MSG_AUTH_UNIMPLEMENTED "Extensiones de seguridad no implementadas"
-#define MSG_NO_FILE_NAME "No nombre de archivo"
-#define MSG_NO_DIRECTORY_NAME "No nombre de directorio"
-#define MSG_NO_RESTART_POINT "No punto de reinicio"
+#define MSG_NO_FILE_NAME "No existe nombre de archivo"
+#define MSG_NO_DIRECTORY_NAME "No existe nombre de directorio"
+#define MSG_NO_RESTART_POINT "No existe punto de reinicio"
 #define MSG_ABOR_SUCCESS "Mientras ves esto ABOR debera haber tenido xito"
 #define MSG_MISSING_ARG "Falta argumento"
 #define MSG_GARBAGE_FOUND "Encontrada basura despus del valor"
@@ -30,8 +30,8 @@
 #define MSG_UNKNOWN_EXTENSION "es una extensin desconocida"
 #define MSG_XDBG_OK "Comando XDBG con xito, el nivel de depuracin es ahora %d"
 #define MSG_UNKNOWN_COMMAND "Comando desconocido"
-#define MSG_TIMEOUT_NOOP "Timeout (no operaciones durante %lu segundos)"
-#define MSG_TIMEOUT_DATA "Timeout (no nuevos datos durante %lu segundos)"
+#define MSG_TIMEOUT_NOOP "Timeout (sin realizar operaciones durante %lu segundos)"
+#define MSG_TIMEOUT_DATA "Timeout (sin nuevos datos durante %lu segundos)"
 #define MSG_SLEEPING "Zzz..."
 #define MSG_ALREADY_LOGGED "Ya ests dentro del sistema"
 #define MSG_ANY_PASSWORD "Cualquier clave funcionar"
@@ -44,7 +44,7 @@
 #define MSG_NO_PASSWORD_NEEDED "No necesito ninguna clave, querido annimo cobarde"
 #define MSG_NOTRUST "Lo siento, pero no te creo"
 #define MSG_WHOAREYOU "Por favor, dime quin eres"
-#define MSG_AUTH_FAILED "Autentificacin fallada, lo siento"
+#define MSG_AUTH_FAILED "Autentificacin fallida, lo siento"
 #define MSG_AUTH_TOOMANY "Demasiados fallos de autentificacin"
 #define MSG_NO_HOMEDIR "Directorio Home no disponible - abortando"
 #define MSG_NO_HOMEDIR2 "%s no existe o es inalcanzable"
@@ -57,7 +57,7 @@
 #define MSG_CURRENT_RESTRICTED_DIR_IS "OK. El directorio restringido actual es %s"
 #define MSG_IS_NOW_LOGGED_IN "%s est ahora dentro del sistema"
 #define MSG_CANT_CHANGE_DIR "No puedo cambiar al directorio %s"
-#define MSG_PATH_TOO_LONG "Path demasiado largo"
+#define MSG_PATH_TOO_LONG "Ruta demasiado larga"
 #define MSG_CANT_PASV "No puedo abrir una conexin pasiva con ese comando obsoleto"
 #define MSG_CANT_PASSIVE "Imposible abrir una conexin pasiva"
 #define MSG_PORTS_BUSY "Todos los puertos TCP reservados estn ocupados"
@@ -68,7 +68,7 @@
 #define MSG_BAD_PORT "Lo siento, pero no me conectar a puertos < 1024"
 #define MSG_NO_FXP "No abrir una conexin a %s (slo a %s)"
 #define MSG_FXP "Transferencia FXP : desde %s hacia %s"
-#define MSG_NO_DATA_CONN "No conexin de datos"
+#define MSG_NO_DATA_CONN "No existe conexin de datos"
 #define MSG_ACCEPT_FAILED "La conexin no se pudo aceptar"
 #define MSG_ACCEPT_SUCCESS "Conexin de datos aceptada"
 #define MSG_CNX_PORT_FAILED "No se pudo abrir conexin de datos con el puerto %d"
@@ -91,14 +91,14 @@
 #define MSG_DELE_TOTAL_FAILURE "Archivo no borrado"
 #define MSG_LOAD_TOO_HIGH \
     "La carga era %3.2f cuando conectaste. No permitimos descargas\n" \
-    "de usuarios annimos cuando la carga es tan alta. Transmisiones son siempre\n" \
-    "permitidas."
+    "de usuarios annimos cuando la carga es tan alta. Las transmisiones se\n" \
+    "permiten siempre."
 #define MSG_OPEN_FAILURE "No se puede abrir %s"
 #define MSG_OPEN_FAILURE2 "No se puede abrir ese archivo"
 #define MSG_STAT_FAILURE "No se encuentra el tamao del archivo"
 #define MSG_STAT_FAILURE2 "No se puede comprobar la existencia del archivo"
-#define MSG_REST_TOO_LARGE_FOR_FILE "Restart offset %lld es demasiado grande para tamao de archivo %lld."
-#define MSG_REST_RESET "Restart offset puesto a 0"
+#define MSG_REST_TOO_LARGE_FOR_FILE "El desplazamiento de reinicio %lld es demasiado grande para el tamao de archivo %lld."
+#define MSG_REST_RESET "Desplazamiento de reinicio puesto a 0"
 #define MSG_NOT_REGULAR_FILE "Slo puedo recuperar archivos comunes"
 #define MSG_NOT_MODERATED \
     "Este archivo ha sido transmitido por un usuario annimo. Todava no ha\n" \
@@ -118,7 +118,7 @@
 #define MSG_TRANSFER_RATE_M "%.3f segundos (medidos aqu), %.2f Mbytes por segundo"
 #define MSG_TRANSFER_RATE_K "%.3f segundos (medidos aqu), %.2f Kbytes por segundo"
 #define MSG_TRANSFER_RATE_B "%.3f segundos (medidos aqu), %.2f bytes por segundo"
-#define MSG_SPACE_FREE_M "%.1f Mbytes free disk space"
+#define MSG_SPACE_FREE_M "%.1f Mbytes de espacio libre en el disco"
 #define MSG_SPACE_FREE_K "%f Kbytes de espacio libre en el disco"
 #define MSG_DOWNLOADED "descargado"
 #define MSG_REST_NOT_NUMERIC "REST necesita un parmetro numrico"
@@ -143,20 +143,20 @@
 #define MSG_TYPE_UNKNOWN "Desconocido TYPE"
 #define MSG_TYPE_SUCCESS "TYPE es ahora"
 #define MSG_STRU_FAILURE "Slo F(ile) est soportado"
-#define MSG_MODE_FAILURE "Please us S(tream) modo"
+#define MSG_MODE_FAILURE "Por favor, use el modo S(tream)"
 #define MSG_RENAME_ABORT "Abortando operacin anterior de renombrado"
 #define MSG_RENAME_RNFR_SUCCESS "RNFR aceptado - archivo existe, preparado para destino"
 #define MSG_FILE_DOESNT_EXIST "Lo siento, pero ese archivo no existe"
 #define MSG_RENAME_ALREADY_THERE "RENAME fall - el archivo de destino ya existe"
 #define MSG_RENAME_NORNFR "Se necesita RNFR antes que RNTO"
-#define MSG_RENAME_FAILURE "Renombrar/mover fallo"
+#define MSG_RENAME_FAILURE "Fallo al renombrar/mover"
 #define MSG_RENAME_SUCCESS "Archivo renombrado o movido con xito"
 #define MSG_NO_SUPERSERVER "Por favor, ejecuta pure-ftpd dentro de un super-servidor (como tcpserver)"
 #define MSG_NO_FTP_ACCOUNT "Imposible encontrar la cuenta 'ftp'"
 #define MSG_CONF_ERR "Error de configuracin"
 #define MSG_NO_VIRTUAL_FILE "Falta el archivo de nombres de usuarios virtuales"
 #define MSG_ILLEGAL_THROTTLING "Valor ilegal para flujo"
-#define MSG_ILLEGAL_TRUSTED_GID "gid confiable para chroot ilegal"
+#define MSG_ILLEGAL_TRUSTED_GID "El GID de confianza chroot es ilegal"
 #define MSG_ILLEGAL_USER_LIMIT "Lmite de usuario ilegal"
 #define MSG_ILLEGAL_FACILITY "Nombre de facilidad desconocido"
 #define MSG_ILLEGAL_CONFIG_FILE_LDAP "Archivo de configuracin LDAP invlido"
@@ -164,7 +164,7 @@
 #define MSG_ILLEGAL_PORTS_RANGE "Rango de puertos ilegal"
 #define MSG_ILLEGAL_LS_LIMITS "Lmites 'ls' ilegales"
 #define MSG_ILLEGAL_FORCE_PASSIVE "IP forzada para conexiones pasivas ilegal"
-#define MSG_ILLEGAL_RATIO "Propocin transmisin/recepcin ilegal"
+#define MSG_ILLEGAL_RATIO "Proporcin de transmisin/recepcin ilegal"
 #define MSG_ILLEGAL_UID_LIMIT "Lmite uid ilegal"
 #define MSG_ILLEGAL_OPTION "Opcin de ejecucin desconocida"
 #define MSG_LDAP_MISSING_BASE "No se encuentra LDAPBaseDN en el archivo de configuracin LDAP"
@@ -172,23 +172,22 @@
 #define MSG_NEW_CONNECTION "Nueva conexin desde %s"
 #define MSG_WELCOME_TO "Bienvenido a"
 #define MSG_MAX_USERS "%lu usuarios (el mximo) estn el sistema, lo siento"
-#define MSG_NB_USERS "Eres el usuario nmero %d de %d permitido"
-#define MSG_WELCOME_TIME "La hora local es ahora %02d:%02d y la carga es %3.2f. Puerto del servidor: %u."
-#define MSG_ANONYMOUS_FTP_ONLY "Slo usuarios annimos estn permitidos aqu"
-#define MSG_RATIOS_EVERYONE "PROPORCIONES ESTN ESTABLECIDAS PARA TODOS :"
+#define MSG_NB_USERS "Eres el usuario nmero %d de %d permitidos"
+#define MSG_WELCOME_TIME "La hora local es ahora %02d:%02d. Puerto del servidor: %u."
+#define MSG_ANONYMOUS_FTP_ONLY "Slo se permite FTP annimo"
+#define MSG_RATIOS_EVERYONE "LAS PROPORCIONES ESTN ESTABLECIDAS PARA TODOS :"
 #define MSG_RATIOS_ANONYMOUS "USUARIOS ANNIMOS ESTN SUJETOS A UNA PROPORCIN UL/DL :"
-#define MSG_RATIOS_RULE "para descargar %u Mb, subir %u Mb de archivos es obligatorio."
+#define MSG_RATIOS_RULE "para descargar %u Mb, es obligatorio subir %u Mb de archivos."
 #define MSG_INFO_IDLE_M "Sers desconectado despus de %lu minutos de inactividad."
-#define MSG_INFO_IDLE_S "Sers desconectados despus de %lu segundos de inactividad."
-#define MSG_INFO_CPU_TIME "Fin de sesin - tiempo CPU empleado: %ld.%03ld segundos."
+#define MSG_INFO_IDLE_S "Sers desconectado despus de %lu segundos de inactividad."
 #define MSG_CANT_READ_FILE "Lo siento, somos incapaces de leer [%s]"
 #define MSG_LS_TRUNCATED "Salida truncada a %u ocurrencias"
 #define MSG_LS_SUCCESS "%u ocurrencias en total"
-#define MSG_LOGOUT "Fin de sesin"
+#define MSG_LOGOUT "Fin de sesin."
 #define MSG_AUTH_FAILED_LOG "Autentificacin fallida para el usuario [%s]"
 #define MSG_ILLEGAL_UMASK "Umask invlida"
-#define MSG_STANDALONE_FAILED "No se ha podido arrancar un servidor independiente"
-#define MSG_NO_ANONYMOUS_LOGIN "Este es un sistema privado - No usuarios annimos"
+#define MSG_STANDALONE_FAILED "No se ha podido ejecutar un servidor independiente"
+#define MSG_NO_ANONYMOUS_LOGIN "Este es un sistema privado - No se permiten usuarios annimos"
 #define MSG_ANONYMOUS_ANY_PASSWORD "Cualquier clave funcionar"
 #define MSG_MAX_USERS_IP "Demasiadas conexiones (%lu) desde esta IP"
 #define MSG_ACTIVE_DISABLED "Modo activo est desactivado"
@@ -213,3 +212,9 @@
 #define MSG_ALIASES_UNKNOWN "Alias desconocido %s."
 #define MSG_ALIASES_BROKEN_FILE "Fichero de alias daado"
 #define MSG_ALIASES_LIST "Los siguientes alias estn disponibles :"
+#define MSG_PERUSER_MAX "No puedo aceptar ms de %lu conexiones del mismo usuario"
+#define MSG_IPV6_OK "Las conexiones IPv6 tambin son bienvenidas en este servidor"
+#define MSG_TLS_INFO "SSL/TLS: Activado %s con %s, %d bits de cifrado"
+#define MSG_TLS_WEAK "SSL/TLS: Cifrado demasiado dbil"
+#define MSG_TLS_NEEDED "Lo siento. No se aceptan sesiones sin cifrar en este servidor.\n" \
+    "Por favor, vuelva a conectar utilizando mecanismos de seguridad SSL/TLS."
