@@ -40,10 +40,10 @@
 #define MSG_USER_OK "Utilisateur %s OK. Veuillez taper votre mot de passe"
 #define MSG_CANT_DO_TWICE "Impossible dans cette session"
 #define MSG_UNABLE_SECURE_ANON "Impossible d'etablir une session FTP anonyme securisee"
-#define MSG_BANDWIDTH_RESTRICTED "La bande-passante est soumise a des quotas"
+#define MSG_BANDWIDTH_RESTRICTED "La bande passante est volontairement restreinte"
 #define MSG_NO_PASSWORD_NEEDED "Pas besoin de mot de passe"
 #define MSG_NOTRUST "Desole, votre compte est inutilisable"
-#define MSG_WHOAREYOU "Qui etes vous?"
+#define MSG_WHOAREYOU "Qui etes vous ?"
 #define MSG_AUTH_FAILED "l'authentification a echouee"
 #define MSG_AUTH_TOOMANY "Trop d'echecs d'authentification"
 #define MSG_NO_HOMEDIR "Les repertoires utilisateurs sont inaccessibles - Abandon"
@@ -66,8 +66,8 @@
 #define MSG_INVALID_IP "Adresse invalide"
 #define MSG_NO_EPSV "Utilisez un client conforme a IPv6 avec le support EPSV"
 #define MSG_BAD_PORT "Desole, connexion impossible sur un port < 1024"
-#define MSG_NO_FXP "Je n'ouvrirais pas de connexion vers %s (seulement vers %s)"
-#define MSG_FXP "Transfert FXP: depuis %s vers %s"
+#define MSG_NO_FXP "Je n'ouvrirai pas de connexion vers %s (seulement vers %s)"
+#define MSG_FXP "Transfert FXP : depuis %s vers %s"
 #define MSG_NO_DATA_CONN "Aucune connexion de donnees"
 #define MSG_ACCEPT_FAILED "La connexion ne peut etre acceptee"
 #define MSG_ACCEPT_SUCCESS "Connexion de donnees acceptee"
@@ -126,7 +126,7 @@
 #define MSG_REST_ASCII_WORKAROUND "Recommence a %lld. Mais en mode ASCII"
 #define MSG_REST_SUCCESS "Recommence a %lld"
 #define MSG_SANITY_DIRECTORY_FAILURE "Nom de repertoire interdit"
-#define MSG_SANITY_FILE_FAILURE "Nom de fichier interdit: %s"
+#define MSG_SANITY_FILE_FAILURE "Nom de fichier interdit : %s"
 #define MSG_MKD_FAILURE "Ne peut creer le repertoire"
 #define MSG_MKD_SUCCESS "Repertoire cree"
 #define MSG_RMD_FAILURE "Impossible de detruire le repertoire"
@@ -151,7 +151,7 @@
 #define MSG_RENAME_NORNFR "RNFR necessaire avant RNTO"
 #define MSG_RENAME_FAILURE "Erreur lors du renommage/deplacement"
 #define MSG_RENAME_SUCCESS "fichier renomme/deplace avec succes"
-#define MSG_NO_SUPERSERVER "Veuillez lancer PureFTPd depuis un super-serveur (comme tcpserver)"
+#define MSG_NO_SUPERSERVER "Veuillez lancer Pure-FTPd depuis un super-serveur (comme tcpserver)"
 #define MSG_NO_FTP_ACCOUNT "Impossible de trouver le compte 'ftp'"
 #define MSG_CONF_ERR "Erreur de configuration"
 #define MSG_NO_VIRTUAL_FILE "Impossible de trouver le fichier des utilisateurs virtuels"
@@ -172,19 +172,18 @@
 #define MSG_NEW_CONNECTION "Nouvelle connexion de %s"
 #define MSG_WELCOME_TO "Bienvenue sur"
 #define MSG_MAX_USERS "%lu utilisateurs (le maximum) sont deja connectes, desole"
-#define MSG_NB_USERS "Vous etes l'utilisateur %d sur les %d autorises"
-#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d et la charge courante est de %3.2f. Port: %u."
-#define MSG_ANONYMOUS_FTP_ONLY "Seules les connexions anonymes sont autorisees"
-#define MSG_RATIOS_EVERYONE "LES RATIOS SONT ACTIVES POUR TOUS LES UTILISATEURS:"
-#define MSG_RATIOS_ANONYMOUS "LES UTILISATEURS ANONYMES SONT SUJETS A DES RATIOS DE UL/DL:"
+#define MSG_NB_USERS "Vous etes l'utilisateur %d sur les %d autorises."
+#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d. Port du serveur : %u."
+#define MSG_ANONYMOUS_FTP_ONLY "Seules les connexions anonymes sont acceptees"
+#define MSG_RATIOS_EVERYONE "LES RATIOS SONT ACTIVES POUR TOUS LES UTILISATEURS :"
+#define MSG_RATIOS_ANONYMOUS "LES UTILISATEURS ANONYMES SONT SUJETS A DES RATIOS DE UL/DL :"
 #define MSG_RATIOS_RULE "Pour downloader %u Mo, vous devez uploader %u Mo."
 #define MSG_INFO_IDLE_M "Vous serez deconnectes apres %lu minutes d'inactivite."
 #define MSG_INFO_IDLE_S "Vous serez deconnectes apres %lu secondes d'inactivite."
-#define MSG_INFO_CPU_TIME "Deloggue - Temps CPU utilise: %ld.%03ld secondes."
 #define MSG_CANT_READ_FILE "Impossible de lire [%s]"
 #define MSG_LS_TRUNCATED "Sortie tronquee a %u elements"
 #define MSG_LS_SUCCESS "%u elements au total"
-#define MSG_LOGOUT "Deloggue"
+#define MSG_LOGOUT "Deloggue."
 #define MSG_AUTH_FAILED_LOG "Erreur d'authentification pour l'utilisateur [%s]"
 #define MSG_ILLEGAL_UMASK "Umask invalide"
 #define MSG_STANDALONE_FAILED "Impossible de demarrer le serveur en standalone"
@@ -198,18 +197,24 @@
 #define MSG_ILLEGAL_TRUSTED_IP "Adresse privilegiee invalide"
 #define MSG_NO_ASCII_RESUME "La reprise ASCII est dangereuse, effacez d'abord le fichier"
 #define MSG_UNKNOWN_ALTLOG "Format d'historique inconnu"
-#define MSG_ACCOUNT_DISABLED "Impossible de se logger sous [%s]: compte desactive"
+#define MSG_ACCOUNT_DISABLED "Impossible de se logger sous [%s] : compte desactive"
 #define MSG_SQL_WRONG_PARMS "Parametre SQL invalide"
 #define MSG_ILLEGAL_CONFIG_FILE_SQL "Fichier de configuration SQL invalide"
 #define MSG_SQL_MISSING_SERVER "Pas de serveur dans la configuration SQL"
 #define MSG_SQL_DOWN "Le serveur SQL ne repond pas"
 #define MSG_ILLEGAL_QUOTA "Quota invalide"
-#define MSG_QUOTA_FILES "%llu fichiers utilises (%d%%) - autorises: %llu fichiers"
-#define MSG_QUOTA_SIZE "%llu Ko utilises (%d%%) - autorises: %llu Ko"
-#define MSG_QUOTA_EXCEEDED "Quota depasse: %s ne sera pas sauvegarde"
+#define MSG_QUOTA_FILES "%llu fichiers utilises (%d%%) - autorises : %llu fichiers"
+#define MSG_QUOTA_SIZE "%llu Ko utilises (%d%%) - autorises : %llu Ko"
+#define MSG_QUOTA_EXCEEDED "Quota depasse : %s ne sera pas sauvegarde"
 #define MSG_AUTH_UNKNOWN "Methode d'authentification inconnue"
 #define MSG_PDB_BROKEN "Impossible de lire le fichier puredb indexe (ou il est dans un vieux format) - Essayez pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s est un raccourci pour %s."
 #define MSG_ALIASES_UNKNOWN "%s est un raccourci inconnu."
 #define MSG_ALIASES_BROKEN_FILE "Le fichier des raccourcis est corrompu"
 #define MSG_ALIASES_LIST "Les raccourcis suivants sont utilisables :"
+#define MSG_PERUSER_MAX "Je ne peux pas accepter plus de %lu connexions du meme utilisateur"
+#define MSG_IPV6_OK "Les connections en IPv6 sont les bienvenues sur ce serveur."
+#define MSG_TLS_INFO "SSL/TLS: Protocole %s activ (%s), chiffrage en %d bits secrets"
+#define MSG_TLS_WEAK "SSL/TLS: Chiffrement trop faible"
+#define MSG_TLS_NEEDED "Desole, les sessions en clair ne sont pas acceptees sur ce serveur.\n" \
+    "Veuillez vous reconnecter en utilisant les mechanismes de securite SSL/TLS."
