@@ -51,7 +51,7 @@
 #define MSG_START_SLASH "/  "
 #define MSG_USER_GROUP_ACCESS " %s   ׷쿡  "
 #define MSG_FXP_SUPPORT "  FXP  밡 մϴ."
-#define MSG_RATIO "/ٿε ( %u:%u )  ּ."
+#define MSG_RATIO "/ٿε (%u:%u)  ּ."
 #define MSG_CHROOT_FAILED "chroot()  Ҽ "
 #define MSG_CURRENT_DIR_IS " 丮: %s"
 #define MSG_CURRENT_RESTRICTED_DIR_IS "ѵ 丮 %s"
@@ -105,7 +105,7 @@
 
 #define MSG_RATIO_DENIAL \
     "˼մϴ.  /ٿ  %u:%u Դϴ.\n" \
-	 " %llu Kb  εϰ %llu Kb ٿε Ͽϴ.\n" \
+     " %llu Kb  εϰ %llu Kb ٿε Ͽϴ.\n" \
     "  ε ּ."
 #define MSG_NO_MORE_TO_DOWNLOAD "ٿε   "
 #define MSG_WINNER "ǻʹ  ģ̴ Ͼ߸ մϴ!"
@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "!~"
 #define MSG_MAX_USERS "%lu  (ִ   ) ̹  ֽϴ. ˼մϴ."
 #define MSG_NB_USERS " %d ° Դϴ. ִ %d "
-#define MSG_WELCOME_TIME " ð %02d:%02d ̸  ϴ %3.2f,  Ʈ %u Դϴ."
+#define MSG_WELCOME_TIME " ð %02d:%02d,  Ʈ %u Դϴ."
 #define MSG_ANONYMOUS_FTP_ONLY "anonymous   մϴ."
 #define MSG_RATIOS_EVERYONE "  /ٿ   :"
 #define MSG_RATIOS_ANONYMOUS "anonymous  /ٿ   :"
 #define MSG_RATIOS_RULE "ٿε %u Mb, ε %u Mb"
 #define MSG_INFO_IDLE_M "%lu   ƹ͵    ϴ."
 #define MSG_INFO_IDLE_S "%lu   ƹ͵    ϴ."
-#define MSG_INFO_CPU_TIME "α׾ƿ - CPU ð: %ld.%03ld "
 #define MSG_CANT_READ_FILE "[%s]   ϴ."
 #define MSG_LS_TRUNCATED "%u   ǥ"
 #define MSG_LS_SUCCESS "%u  ġ"
-#define MSG_LOGOUT "α׾ƿ"
+#define MSG_LOGOUT "α׾ƿ."
 #define MSG_AUTH_FAILED_LOG "[%s]   "
 #define MSG_ILLEGAL_UMASK "߸ umask"
 #define MSG_STANDALONE_FAILED "standalone   Ҽ ϴ."
@@ -215,3 +214,7 @@
 #define MSG_ALIASES_LIST " Ī  :"
 #define MSG_PERUSER_MAX "  %lu  ̻   ʽϴ."
 #define MSG_IPV6_OK "  IPv6 ᵵ մϴ."
+#define MSG_TLS_INFO "SSL/TLS: Enabled %s with %s, %d secret bits cipher"
+#define MSG_TLS_WEAK "SSL/TLS: Cipher too weak"
+#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
+    "Please reconnect using SSL/TLS security mechanisms."
