@@ -1,85 +1,85 @@
 #define MSG_TIMEOUT "Timeout"
-#define MSG_CAPABILITIES "Kan ikke endre muligheter"
-#define MSG_CLIENT_CLOSED_CNX "Klienten lukket tilkoplingen"
-#define MSG_CLIENT_READ_ERR "Lese feil fra klienten"
-#define MSG_CANT_OPEN_CNX "Kan ikke pne tilkoplingen"
-#define MSG_CANT_CREATE_DATA_SOCKET "Kan ikke opprette data sokkel"
+#define MSG_CAPABILITIES "Kan ikke endre egenskaper"
+#define MSG_CLIENT_CLOSED_CNX "Klienten lukket tilkoblingen"
+#define MSG_CLIENT_READ_ERR "Lesefeil fra klienten"
+#define MSG_CANT_OPEN_CNX "Kan ikke pne tilkoblingen"
+#define MSG_CANT_CREATE_DATA_SOCKET "Kan ikke opprette datasokkel"
 #define MSG_DEBUG_CLIENT_IS "Klientens adresse er"
-#define MSG_SYNTAX_ERROR_IP "Syntaks feil i IP adresse"
-#define MSG_PORT_SUCCESSFUL "PORT kommando lykktes"
+#define MSG_SYNTAX_ERROR_IP "Syntaks-feil i IP-adresse"
+#define MSG_PORT_SUCCESSFUL "PORT-kommando lyktes"
 #define MSG_ONLY_IPV4V6 "Kun IPv4 og IPv6 er stttet (1,2)"
 #define MSG_ONLY_IPV4 "Kun IPv4 er stttet (1)"
 #define MSG_TIMEOUT_PARSER "Timeout - prv  skrive litt raskere neste gang"
 #define MSG_LINE_TOO_LONG "Linjen er for lang"
 #define MSG_LOG_OVERFLOW "Klienten prvde  overfylle kommandolinjens buffer"
-#define MSG_GOODBYE "Farvell. Du lastet opp %llu og lastet ned %llu kbytes."
+#define MSG_GOODBYE "Farvel! Du lastet opp %llu og lastet ned %llu kbytes."
 #define MSG_DEBUG_COMMAND "Kommando"
-#define MSG_IS_YOUR_CURRENT_LOCATION "er din nvrende possisjon"
+#define MSG_IS_YOUR_CURRENT_LOCATION "er din nvrende posisjon"
 #define MSG_NOT_LOGGED_IN "Du er ikke logget inn"
 #define MSG_AUTH_UNIMPLEMENTED "Sikkerhetsutvidelse er ikke implementert"
-#define MSG_NO_FILE_NAME "Ingen filnavn"
-#define MSG_NO_DIRECTORY_NAME "Ingen katalognavn"
-#define MSG_NO_RESTART_POINT "Ingen restart punkt"
-#define MSG_ABOR_SUCCESS "Siden du ser denne ABOR, s er den nok vellykket"
+#define MSG_NO_FILE_NAME "Intet filnavn"
+#define MSG_NO_DIRECTORY_NAME "Intet katalognavn"
+#define MSG_NO_RESTART_POINT "Intet restartpunkt"
+#define MSG_ABOR_SUCCESS "Siden du ser dette, m ABOR ha vrt vellykket"
 #define MSG_MISSING_ARG "Manglende argument"
 #define MSG_GARBAGE_FOUND "Sppel funnet etter verdi"
-#define MSG_VALUE_TOO_LARGE "Verdi for stor"
-#define MSG_IDLE_TIME "Innaktiv tid er sett til %lu sekunder"
-#define MSG_SITE_HELP "Flgende SITE kommandoer er tilgjengelige"
-#define MSG_BAD_CHMOD "Feil rettigheter"
+#define MSG_VALUE_TOO_LARGE "Verdi er for stor"
+#define MSG_IDLE_TIME "Inaktiv tid er satt til %lu sekunder"
+#define MSG_SITE_HELP "Flgende SITE-kommandoer er tilgjengelige"
+#define MSG_BAD_CHMOD "Ugyldige rettigheter"
 #define MSG_UNKNOWN_EXTENSION "er en ukjent utvidelse"
 #define MSG_XDBG_OK "XDBG kommando vellykket, debug niv er n %d"
 #define MSG_UNKNOWN_COMMAND "Ukjent kommando"
 #define MSG_TIMEOUT_NOOP "Timeout (ingenting utfrt p %lu sekunder)"
-#define MSG_TIMEOUT_DATA "Timeout (ingen ny data p %lu sekunder)"
+#define MSG_TIMEOUT_DATA "Timeout (ingen nye data p %lu sekunder)"
 #define MSG_SLEEPING "Zzz..."
 #define MSG_ALREADY_LOGGED "Du er allerede logget inn"
-#define MSG_ANY_PASSWORD "Et hvilket som helst passord virker"
+#define MSG_ANY_PASSWORD "Et hvilket som helst passord duger"
 #define MSG_ANONYMOUS_LOGGED "Anonym bruker er logget inn"
-#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonym bruker er logget p virtuel FTP"
-#define MSG_USER_OK "Bruker %s OK. Det kreves passord."
+#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonym bruker er logget p virtuell FTP"
+#define MSG_USER_OK "Bruker %s OK. Det kreves passord"
 #define MSG_CANT_DO_TWICE "Vi kan ikke gjre det i denne forbindelsen"
-#define MSG_UNABLE_SECURE_ANON "Kan ikke opprette en sikker anonym FTP forbindelse"
-#define MSG_BANDWIDTH_RESTRICTED "Din bndbredde er begrenset"
+#define MSG_UNABLE_SECURE_ANON "Kan ikke opprette en sikker anonym FTP-forbindelse"
+#define MSG_BANDWIDTH_RESTRICTED "Din bndbredde er begrenset."
 #define MSG_NO_PASSWORD_NEEDED "Hvilket som helst passord vil fungere"
 #define MSG_NOTRUST "Beklager, men jeg stoler ikke p deg"
 #define MSG_WHOAREYOU "Vennligst fortell meg hvem du er"
-#define MSG_AUTH_FAILED "Godkjenning misslyktes, beklager"
-#define MSG_AUTH_TOOMANY "For mange misslykkede godkjennings forsk"
-#define MSG_NO_HOMEDIR "Hjemme katalogen er ikke tilgjengelig - avbryter"
-#define MSG_NO_HOMEDIR2 "%s eksisterer ikke eller kan ikke nes"
+#define MSG_AUTH_FAILED "Godkjenning mislyktes, beklager"
+#define MSG_AUTH_TOOMANY "For mange mislykkede innloggingsforsk"
+#define MSG_NO_HOMEDIR "Hjemmekatalogen er ikke tilgjengelig - avbryter"
+#define MSG_NO_HOMEDIR2 "%s eksisterer ikke eller kan ikke ns"
 #define MSG_START_SLASH "Starter i /"
 #define MSG_USER_GROUP_ACCESS "Brukeren %s har gruppetilgang til"
-#define MSG_FXP_SUPPORT "Denne serveren sttter FXP overfring"
-#define MSG_RATIO "Du m respektere %u:%u (UL/DL) forholdet"
-#define MSG_CHROOT_FAILED "Kan ikke sette opp en sikker chroot() celle"
+#define MSG_FXP_SUPPORT "Denne serveren sttter FXP-overfring"
+#define MSG_RATIO "Du m respektere en %u:%u (UL/DL)-ratio"
+#define MSG_CHROOT_FAILED "Kan ikke sette opp en sikker chroot()-celle"
 #define MSG_CURRENT_DIR_IS "OK. Nvrende katalog er %s"
-#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Nverende begrenset mappe er %s"
+#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Nvrende begrenset mappe er %s"
 #define MSG_IS_NOW_LOGGED_IN "%s er n logget inn"
 #define MSG_CANT_CHANGE_DIR "Kan ikke skifte katalog til %s"
 #define MSG_PATH_TOO_LONG "Sti for lang"
-#define MSG_CANT_PASV "Du kan ikke bruke PASV p IPv6 tilkoplinger. Bruk heller EPSV."
+#define MSG_CANT_PASV "Du kan ikke bruke PASV p IPv6 tilkoblinger. Bruk heller EPSV."
 #define MSG_CANT_PASSIVE "Kan ikke pne en passiv forbindelse"
 #define MSG_PORTS_BUSY "Alle reserverte TCP porter er opptatt"
-#define MSG_GETSOCKNAME_DATA "Kan ikke identifisere den lokale data sokkelen"
-#define MSG_GETPEERNAME "Kan ikke identifisere den lokale data sokkelen"
-#define MSG_INVALID_IP "Beklager, ugyldig adresse"
+#define MSG_GETSOCKNAME_DATA "Kan ikke identifisere den lokale datasokkelen"
+#define MSG_GETPEERNAME "Kan ikke identifisere den lokale datasokkelen"
+#define MSG_INVALID_IP "Beklager, ugyldig IP-adresse"
 #define MSG_NO_EPSV "Vennligst bruk en klient som sttter IPv6 med EPSV"
-#define MSG_BAD_PORT "Beklager, men jeg kan ikke kople til porter < 1024"
+#define MSG_BAD_PORT "Beklager, men jeg kan ikke koble til porter < 1024"
 #define MSG_NO_FXP "Jeg kan ikke pne en forbindelse til %s (bare til %s)"
-#define MSG_FXP "FXP overfring: fra %s til %s"
-#define MSG_NO_DATA_CONN "Ingen data forbindelse"
+#define MSG_FXP "FXP-overfring: fra %s til %s"
+#define MSG_NO_DATA_CONN "Ingen dataforbindelse"
 #define MSG_ACCEPT_FAILED "Kunne ikke godkjenne forbindelsen"
-#define MSG_ACCEPT_SUCCESS "Data forbindelse godkjent"
-#define MSG_CNX_PORT_FAILED "Kan ikke pne data forbindelse til port %d"
-#define MSG_CNX_PORT "Kople til port %d"
+#define MSG_ACCEPT_SUCCESS "Dataforbindelse godkjent"
+#define MSG_CNX_PORT_FAILED "Kan ikke pne dataforbindelse til port %d"
+#define MSG_CNX_PORT "Kobler til port %d"
 #define MSG_ANON_CANT_MKD "Beklager, anonyme brukere kan ikke opprette kataloger"
 #define MSG_ANON_CANT_RMD "Beklager, anonyme brukere kan ikke slette kataloger"
 #define MSG_ANON_CANT_RENAME "Anonyme brukere kan ikke flytte eller endre navn p filer"
 #define MSG_ANON_CANT_CHANGE_PERMS "Anonyme brukere kan ikke endre rettigheter"
 #define MSG_GLOB_NO_MEMORY "Slutt p minnet under gjennomgang av %s"
-#define MSG_PROBABLY_DENIED "(Dette betyr sansynligvis 'Ingen tilgang')"
-#define MSG_GLOB_READ_ERROR "Lese feil under gjennomgang av %s"
+#define MSG_PROBABLY_DENIED "(Dette betyr sannsynligvis 'Ingen tilgang')"
+#define MSG_GLOB_READ_ERROR "Lesefeil under gjennomgang av %s"
 #define MSG_GLOB_NO_MATCH "Ingen %s i %s"
 #define MSG_CHMOD_FAILED "Kunne ikke endre rettigheter p %s"
 #define MSG_CHMOD_SUCCESS "Rettigheter endret p %s"
@@ -97,22 +97,22 @@
 #define MSG_OPEN_FAILURE2 "Kan ikke pne den filen"
 #define MSG_STAT_FAILURE "Kan ikke finne filstrrelsen"
 #define MSG_STAT_FAILURE2 "Kan ikke sjekke om filen finnes"
-#define MSG_REST_TOO_LARGE_FOR_FILE "Gjenstart punkt %lld er for stor for filstrrelse %lld."
-#define MSG_REST_RESET "Gjenstart punkt satt til 0"
+#define MSG_REST_TOO_LARGE_FOR_FILE "Gjenstartpunkt %lld er for stor for filstrrelse %lld."
+#define MSG_REST_RESET "Gjenstartpunkt satt til 0"
 #define MSG_NOT_REGULAR_FILE "Jeg kan bare motta vanlige filer"
 #define MSG_NOT_MODERATED \
     "Denne filen er lastet opp av en anonym bruker. Den er enn\n" \
     "ikke blitt godkjent for nedlasting av administratorene."
 #define MSG_RATIO_DENIAL \
-    "Beklager, men opplastings/nedlastings forholdet er %u:%u .\n" \
-    "Du har lastet opp%llu Kb og lastet ned %llu Kb.\n" \
+    "Beklager, men opplastings/nedlastings-forholdet er %u:%u .\n" \
+    "Du har lastet opp %llu Kb og lastet ned %llu Kb.\n" \
     "Vennligst last opp noe fr du prver  laste ned."
 #define MSG_NO_MORE_TO_DOWNLOAD "Det er ingenting igjen  laste ned"
 #define MSG_WINNER "Datamaskinen er din venn. Stol p datamaskinen"
 #define MSG_KBYTES_LEFT "%.1f kbytes igjen  hente"
 #define MSG_ABORTED "Overfring avbrutt"
-#define MSG_DATA_WRITE_FAILED "Feil under skriving til data forbindelsen"
-#define MSG_DATA_READ_FAILED "Feil under lesing fra data forbindelsen"
+#define MSG_DATA_WRITE_FAILED "Feil under skriving til dataforbindelsen"
+#define MSG_DATA_READ_FAILED "Feil under lesing fra dataforbindelsen"
 #define MSG_MMAP_FAILED "Kunne ikke legge filen i minnet"
 #define MSG_WRITE_FAILED "Feil under skriving til fil"
 #define MSG_TRANSFER_RATE_M "%.3f sekunder (mlt her), %.2f Mbytes per sekund"
@@ -121,8 +121,8 @@
 #define MSG_SPACE_FREE_M "%.1f Mbytes ledig disk plass"
 #define MSG_SPACE_FREE_K "%f Kbytes ledig disk plass"
 #define MSG_DOWNLOADED "nedlastet"
-#define MSG_REST_NOT_NUMERIC "REST skal bruke et numerisk parameter"
-#define MSG_REST_ASCII_STRICT "Svar markr m vre 0 i ASCII mode"
+#define MSG_REST_NOT_NUMERIC "REST krever en numerisk parameter"
+#define MSG_REST_ASCII_STRICT "Svar-markr m vre 0 i ASCII mode"
 #define MSG_REST_ASCII_WORKAROUND "Startet p nytt ved %lld. Men vi er i ASCII mode"
 #define MSG_REST_SUCCESS "Starter p nytt ved %lld"
 #define MSG_SANITY_DIRECTORY_FAILURE "Fordbudt katalognavn"
@@ -142,79 +142,79 @@
 #define MSG_TYPE_8BIT_FAILURE "Kun 8-bit bytes er stttet, vi er ikke 10 r tilbake"
 #define MSG_TYPE_UNKNOWN "Ukjent TYPE"
 #define MSG_TYPE_SUCCESS "TYPE er n"
-#define MSG_STRU_FAILURE "Kun F(il) er stttet"
-#define MSG_MODE_FAILURE "Venligst bruk S(tream) mode"
-#define MSG_RENAME_ABORT "Avbryter forige omdpings oppgave"
+#define MSG_STRU_FAILURE "Kun F(ile) er stttet"
+#define MSG_MODE_FAILURE "Vennligst bruk S(tream) mode"
+#define MSG_RENAME_ABORT "Avbryter forrige omdpingsoppgave"
 #define MSG_RENAME_RNFR_SUCCESS "RNFR godkjent - filen finnes, klar for destinasjon"
 #define MSG_FILE_DOESNT_EXIST "Beklager, men den filen finnes ikke"
-#define MSG_RENAME_ALREADY_THERE "RENAME misslykktes - destinasjons filen finnes allerede"
+#define MSG_RENAME_ALREADY_THERE "RENAME mislyktes - destinasjonsfilen finnes allerede"
 #define MSG_RENAME_NORNFR "Trenger RNFR fr RNTO"
-#define MSG_RENAME_FAILURE "Omdping/flyttings feil"
+#define MSG_RENAME_FAILURE "Omdpings/flyttingsfeil"
 #define MSG_RENAME_SUCCESS "Filen er omdpt eller flyttet"
-#define MSG_NO_SUPERSERVER "Venligst kjr pure-ftpd fra en super-server (f.eks tcpserver)"
-#define MSG_NO_FTP_ACCOUNT "Kunne ikke finne 'ftp' kontoen"
-#define MSG_CONF_ERR "Konfigurasjons feil"
-#define MSG_NO_VIRTUAL_FILE "Virtuelle brukers navn mangler"
-#define MSG_ILLEGAL_THROTTLING "Ulovlig verdi for throttle"
-#define MSG_ILLEGAL_TRUSTED_GID "Ulovlig gid for chroot"
-#define MSG_ILLEGAL_USER_LIMIT "Ulovlig bruker begrensing"
-#define MSG_ILLEGAL_FACILITY "Ukjent fasilitets navn"
-#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Feil i LDAP konfigurasjons fil"
-#define MSG_ILLEGAL_LOAD_LIMIT "Ulovlig load grense"
-#define MSG_ILLEGAL_PORTS_RANGE "Ulovlig port omrde"
-#define MSG_ILLEGAL_LS_LIMITS "Ulovlig 'ls' begrensing"
-#define MSG_ILLEGAL_FORCE_PASSIVE "Ulovlig tvungen IP til passive forbindelser"
-#define MSG_ILLEGAL_RATIO "Ulovlig opplastings/nedlastings forhold"
-#define MSG_ILLEGAL_UID_LIMIT "Ulovlig uid grense"
-#define MSG_ILLEGAL_OPTION "Ukjent run-time valg"
-#define MSG_LDAP_MISSING_BASE "Mangler LDAPBaseDN i LDAP konfigurasjons filen"
-#define MSG_LDAP_WRONG_PARMS "Feil LDAP parameter"
-#define MSG_NEW_CONNECTION "Ny tilkopling fra %s"
+#define MSG_NO_SUPERSERVER "Vennligst kjr pure-ftpd fra en super-server (f.eks. tcpserver)"
+#define MSG_NO_FTP_ACCOUNT "Kunne ikke finne 'ftp'-kontoen"
+#define MSG_CONF_ERR "Konfigurasjonsfeil"
+#define MSG_NO_VIRTUAL_FILE "Mangler navn p virtuell bruker"
+#define MSG_ILLEGAL_THROTTLING "Ugyldig verdi for throttle"
+#define MSG_ILLEGAL_TRUSTED_GID "Ugyldig 'trusted gid' for chroot"
+#define MSG_ILLEGAL_USER_LIMIT "Ugyldig brukerbegrensning"
+#define MSG_ILLEGAL_FACILITY "Ukjent fasilitetsnavn"
+#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Feil i LDAP-konfigurasjonsfil"
+#define MSG_ILLEGAL_LOAD_LIMIT "Ugyldig load-grense"
+#define MSG_ILLEGAL_PORTS_RANGE "Ugyldig port-omrde"
+#define MSG_ILLEGAL_LS_LIMITS "Ugyldig 'ls'-begrensing"
+#define MSG_ILLEGAL_FORCE_PASSIVE "Ugyldig tvungen IP-adresse til passive forbindelser"
+#define MSG_ILLEGAL_RATIO "Ugyldig opplastings/nedlastings-forhold"
+#define MSG_ILLEGAL_UID_LIMIT "Ugyldig uid-grense"
+#define MSG_ILLEGAL_OPTION "Ukjent run-time-valg"
+#define MSG_LDAP_MISSING_BASE "Mangler LDAPBaseDN i LDAP-konfigurasjonsfilen"
+#define MSG_LDAP_WRONG_PARMS "Feil LDAP-parameter"
+#define MSG_NEW_CONNECTION "Ny tilkobling fra %s"
 #define MSG_WELCOME_TO "Velkommen til"
 #define MSG_MAX_USERS "%lu brukere (maks) er allerede logget p"
 #define MSG_NB_USERS "Du er bruker nummer %d av %d tillatte"
 #define MSG_WELCOME_TIME "Den lokale tiden er n %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Kun anonym FTP er tillatt her"
-#define MSG_RATIOS_EVERYONE "FORHOLD ER SATT P FOR ALLE:"
-#define MSG_RATIOS_ANONYMOUS "ANONYME BRUKERE FR ET UL/DL FORHOLD:"
-#define MSG_RATIOS_RULE "for  laste ned %u Mb, s last opp %u Mb."
-#define MSG_INFO_IDLE_M "Du blir koplet fra etter %lu minutt innaktivitet."
-#define MSG_INFO_IDLE_S "Du blir koplet fra etter %lu sekund innaktivitet."
+#define MSG_RATIOS_EVERYONE "RATIO ER SATT P FOR ALLE:"
+#define MSG_RATIOS_ANONYMOUS "ANONYME BRUKERE BLIR UNDERLAGT UL/DL-RATIO:"
+#define MSG_RATIOS_RULE "for  laste ned %u Mb, m du laste opp %u Mb med godsaker."
+#define MSG_INFO_IDLE_M "Du blir koblet fra etter %lu minutters inaktivitet."
+#define MSG_INFO_IDLE_S "Du blir koblet fra etter %lu sekunders inaktivitet."
 #define MSG_CANT_READ_FILE "Beklager, kunne ikke lese [%s]"
-#define MSG_LS_TRUNCATED "Date er avrundet til %u treff"
+#define MSG_LS_TRUNCATED "Resultat er avkortet til %u treff"
 #define MSG_LS_SUCCESS "%u treff totalt"
 #define MSG_LOGOUT "Logg ut."
-#define MSG_AUTH_FAILED_LOG "Godkjennelse misslyktes for [%s]"
+#define MSG_AUTH_FAILED_LOG "Godkjennelse mislyktes for [%s]"
 #define MSG_ILLEGAL_UMASK "Feil umask"
 #define MSG_STANDALONE_FAILED "Kan ikke starte en standalone server"
 #define MSG_NO_ANONYMOUS_LOGIN "Dette er et privat system - Ingen anonyme innlogginger tillatt"
 #define MSG_ANONYMOUS_ANY_PASSWORD "Et hvilket som helst passord virker"
-#define MSG_MAX_USERS_IP "For mangen forbindelser (%lu) fra denne IPen"
+#define MSG_MAX_USERS_IP "For mange forbindelser (%lu) fra denne IP-adressen"
 #define MSG_ACTIVE_DISABLED "Active mode er sltt av"
-#define MSG_TRANSFER_SUCCESSFUL "Filen er vellykket overfrt"
-#define MSG_NO_DISK_SPACE "Disken er full - venligst last opp senere"
+#define MSG_TRANSFER_SUCCESSFUL "Overfringen av filen var vellykket"
+#define MSG_NO_DISK_SPACE "Disken er full - vennligst last opp senere"
 #define MSG_OUT_OF_MEMORY "Minnet er oppbrukt"
-#define MSG_ILLEGAL_TRUSTED_IP "Ulovlig plitelig IP adresse"
+#define MSG_ILLEGAL_TRUSTED_IP "Ugyldig plitelig IP-adresse"
 #define MSG_NO_ASCII_RESUME " fortsette p en ASCII fil er usikkert, slett filen frst."
-#define MSG_UNKNOWN_ALTLOG "Ukjent logg format"
+#define MSG_UNKNOWN_ALTLOG "Ukjent loggformat"
 #define MSG_ACCOUNT_DISABLED "Kan ikke logge inn som [%s]: kontoen er stengt"
-#define MSG_SQL_WRONG_PARMS "Feil SQL paramertre"
-#define MSG_ILLEGAL_CONFIG_FILE_SQL "delagt SQL konfigurasjons fil"
-#define MSG_SQL_MISSING_SERVER "Mangler server i SQL konfigurasjons fila"
-#define MSG_SQL_DOWN "SQL serveren ser ut til  vre nede"
-#define MSG_ILLEGAL_QUOTA "Feil quota"
-#define MSG_QUOTA_FILES "%llu filer blir brukt (%d%%) - lovlig: %llu filer"
-#define MSG_QUOTA_SIZE "%llu Kbytes blir brukt (%d%%) - lovlig: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Quota overskredet: %s blir ikke lagret"
-#define MSG_AUTH_UNKNOWN "Ukjent godkjennelses metode"
-#define MSG_PDB_BROKEN "Kan ikke lese den indekserte puredb filen (eller den er i gammelt format) - Prv pure-pw mkdb"
+#define MSG_SQL_WRONG_PARMS "Feil SQL-parametere"
+#define MSG_ILLEGAL_CONFIG_FILE_SQL "Ugyldig SQL-konfigurasjonsfil"
+#define MSG_SQL_MISSING_SERVER "Mangler server i SQL-konfigurasjonsfilen"
+#define MSG_SQL_DOWN "SQL-serveren ser ut til  vre nede"
+#define MSG_ILLEGAL_QUOTA "Ugyldig quota"
+#define MSG_QUOTA_FILES "%llu filer blir brukt (%d%%) - tillatt: %llu filer"
+#define MSG_QUOTA_SIZE "%llu Kbytes blir brukt (%d%%) - tillatt: %llu Kb"
+#define MSG_QUOTA_EXCEEDED "Quota oversteget: %s blir ikke lagret"
+#define MSG_AUTH_UNKNOWN "Ukjent godkjennelsesmetode"
+#define MSG_PDB_BROKEN "Kan ikke lese den indekserte puredb-filen (eller den er i gammelt format) - Prv pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s er et alias for %s."
 #define MSG_ALIASES_UNKNOWN "Ukjent alias %s."
-#define MSG_ALIASES_BROKEN_FILE "delagt alias fil"
-#define MSG_ALIASES_LIST "Flgende alias er tilgjengelige :"
-#define MSG_PERUSER_MAX "Kan ikke tillate mer enn %lu tilkoplinger fra samme bruker"
-#define MSG_IPV6_OK "IPv6 forbindelser er ogs velkommen p denne serveren"
+#define MSG_ALIASES_BROKEN_FILE "delagt alias-fil"
+#define MSG_ALIASES_LIST "Flgende alias er tilgjengelige:"
+#define MSG_PERUSER_MAX "Kan ikke akseptere mer enn %lu tilkoblinger fra samme bruker"
+#define MSG_IPV6_OK "IPv6-forbindelser er ogs velkomne p denne serveren"
 #define MSG_TLS_INFO "SSL/TLS: Aktivert %s med %s, %d bits kryperingsnkkel"
 #define MSG_TLS_WEAK "SSL/TLS: Krypteringsnkkelen er for svak"
-#define MSG_TLS_NEEDED "Beklager, klartekst sessjoner er ikke tillatt p denne serveren.\n" \
-    "Vr vennlig  kople til p ny med SSL/TLS aktivert."
+#define MSG_TLS_NEEDED "Beklager, klartekst-forbindelser er ikke tillatt p denne serveren.\n" \
+    "Vr vennlig  koble til p nytt ved bruk av SSL/TLS-sikkerhetsmekanismer."
