@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "Bine ati venit pe"
 #define MSG_MAX_USERS "%lu utilizatori (maximul) sint deja logati"
 #define MSG_NB_USERS "Sineti utilizatorul cu numarul %d din %d permisi"
-#define MSG_WELCOME_TIME "Timpul local este acum %02d:%02d si incarcarea este %3.2f. Port server: %u."
+#define MSG_WELCOME_TIME "Timpul local este acum %02d:%02d. Port server: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Aici este permis numai acces FTP anonim"
 #define MSG_RATIOS_EVERYONE "COTELE SINT ACTIVATE PENTRU ORICINE :"
 #define MSG_RATIOS_ANONYMOUS "UTILIZATORII ANONIMI SINT SUPUSI UNEI COTE UL/DL :"
 #define MSG_RATIOS_RULE "pentru a download-a %u Mb, este obligatoriu sa upload-ati %u Mb de alte fisiere."
 #define MSG_INFO_IDLE_M "Veti fi deconectat dupa %lu minute de inactivitate."
 #define MSG_INFO_IDLE_S "Veti fi deconectat dupa %lu secunde de inactivitate."
-#define MSG_INFO_CPU_TIME "Iesire - Timp de CPU consumat: %ld.%03ld secunde."
 #define MSG_CANT_READ_FILE "Nu am putut citi [%s]"
 #define MSG_LS_TRUNCATED "Rezultat trunchiat la %u potriviri"
 #define MSG_LS_SUCCESS "%u potriviri in total"
-#define MSG_LOGOUT "Iesire"
+#define MSG_LOGOUT "Iesire."
 #define MSG_AUTH_FAILED_LOG "Autentificare esuata pentru utilizatorul [%s]"
 #define MSG_ILLEGAL_UMASK "Valoare umask eronata"
 #define MSG_STANDALONE_FAILED "Nu am putut starta un server de sine statator"
@@ -208,8 +207,14 @@
 #define MSG_QUOTA_SIZE "%llu Kocteti utilizati (%d%%) - autorizat: %llu Kocteti"
 #define MSG_QUOTA_EXCEEDED "Cota depasita: %s nu va fi salvat"
 #define MSG_AUTH_UNKNOWN "Metoda de autentificare necunoscuta"
-#define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
-#define MSG_ALIASES_ALIAS "%s is an alias for %s."
-#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
-#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
-#define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_PDB_BROKEN "Nu pot citi fisierul puredb indexat (probabil e in format vechi) - Incercati pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s este un alias pentru %s."
+#define MSG_ALIASES_UNKNOWN "Aliasul %s este necunoscut."
+#define MSG_ALIASES_BROKEN_FILE "Fisier de aliasuri defect"
+#define MSG_ALIASES_LIST "Sint disponibile urmatoarele aliasuri: "
+#define MSG_PERUSER_MAX "Nu pot accepta mai mult de %lu conexiuni de la acelasi utilizator"
+#define MSG_IPV6_OK "Conexiunile IPv6 sint acceptate de catre acest server"
+#define MSG_TLS_INFO "SSL/TLS: Am activat %s cu %s, criptare cu %d biti"
+#define MSG_TLS_WEAK "SSL/TLS: Sistem de criptare prea slab"
+#define MSG_TLS_NEEDED "Sesiunile in text clar nu sint acceptate pe acest server.\n" \
+    "Reconectati-va utilizind mecanismele de securitate SSL/TLS."
