@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "Vitajte na"
 #define MSG_MAX_USERS "Lutujem, ale %lu (maximum) pouzivatelov je uz prihlasenych"
 #define MSG_NB_USERS "Ste pouzivatel cislo %d z %d povolenych"
-#define MSG_WELCOME_TIME "Lokalny cas je teraz %02d:%02d a systemova zataz je %3.2f. Serverovy port: %u."
+#define MSG_WELCOME_TIME "Lokalny cas je teraz %02d:%02d. Serverovy port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Tu je povoleny len anonymny pristup"
 #define MSG_RATIOS_EVERYONE "VSETCI POUZIVATELIA MUSIA DODRZAT POMER UL/DL :"
 #define MSG_RATIOS_ANONYMOUS "ANONYMNI POUZIVATELIA MUSIA DODRZAT POMER UL/DL :"
 #define MSG_RATIOS_RULE "na download %u megabajtov musite uploadnut %u Mb."
 #define MSG_INFO_IDLE_M "Budete odpojeny po %lu minutach neaktivity."
 #define MSG_INFO_IDLE_S "Budete odpojeny po %lu sekundach neaktivity."
-#define MSG_INFO_CPU_TIME "Logout - pouzity procesorovy cas: %ld.%03ld sekund."
 #define MSG_CANT_READ_FILE "Lutujem, nebol som schopny precitat [%s]"
 #define MSG_LS_TRUNCATED "Vystup skrateny na %u zhod"
 #define MSG_LS_SUCCESS "Spolu %u zhod"
-#define MSG_LOGOUT "Logout"
+#define MSG_LOGOUT "Logout."
 #define MSG_AUTH_FAILED_LOG "Autentifikacia uzivatela zlyhala [%s]"
 #define MSG_ILLEGAL_UMASK "Neplatna maska"
 #define MSG_STANDALONE_FAILED "Nemozem spustit samostatny server"
@@ -213,3 +212,9 @@
 #define MSG_ALIASES_UNKNOWN "Neznamy alias %s."
 #define MSG_ALIASES_BROKEN_FILE "Poskodeny subor aliasov"
 #define MSG_ALIASES_LIST "Nasledovne aliasy su dostupne :"
+#define MSG_PERUSER_MAX "Nemozem akceptovat viac ako %lu pripojeni od toho isteho pouzivatela"
+#define MSG_IPV6_OK "Pripojenia pomocou IPv6 su tiez vitane na tomto serveri"
+#define MSG_TLS_INFO "SSL/TLS: Zapnute %s pouziva sifru %s, %d tajnych bitov"
+#define MSG_TLS_WEAK "SSL/TLS: Sifra je prilis slaba"
+#define MSG_TLS_NEEDED "Prepacte, ale nesifrovane spojenia nie su povolene na tomto serveri.\n" \
+    "Pri najblizsom spojeni pouzite zabezpecovacie mechanizmy SSL/TLS."
