@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "Vlkommen till"
 #define MSG_MAX_USERS "%lu anvndare (maximala antalet) r redan inloggade"
 #define MSG_NB_USERS "Du r anvndare nummer %d av %d tilltna"
-#define MSG_WELCOME_TIME "Lokal tid r nu %02d:%02d och belastningen r %3.2f. Server port: %u."
+#define MSG_WELCOME_TIME "Lokal tid r nu %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Endast anonym FTP r tillten"
 #define MSG_RATIOS_EVERYONE "RATIOS r aktiverat fr ALLA:"
 #define MSG_RATIOS_ANONYMOUS "ANONYMA anvndare utstts fr en UL/DL kvot:"
 #define MSG_RATIOS_RULE "fr att ladda ned %u Mb, r det ndvndigt att ladda upp %u Mb."
 #define MSG_INFO_IDLE_M "Du kommer att kopplas ned efter %lu minuters inaktivitet."
 #define MSG_INFO_IDLE_S "Du kommer att kopplas ned efter %lu sekunders inaktivitet."
-#define MSG_INFO_CPU_TIME "Logout - anvnd CPU tid: %ld.%03ld sekunder."
 #define MSG_CANT_READ_FILE "Kan ej lsa [%s]"
 #define MSG_LS_TRUNCATED "Utdata trunkeras till %u trffar"
 #define MSG_LS_SUCCESS "%u trffar totalt"
-#define MSG_LOGOUT "Logout"
+#define MSG_LOGOUT "Logout."
 #define MSG_AUTH_FAILED_LOG "Behrighetskontroll misslyckas fr anvndare [%s]"
 #define MSG_ILLEGAL_UMASK "Ogiltig umask"
 #define MSG_STANDALONE_FAILED "Kan ej starta standalone server"
@@ -215,3 +214,7 @@
 #define MSG_ALIASES_LIST "Fljande alias r tillgngliga :"
 #define MSG_PERUSER_MAX "Jag kan inte acceptera fler n %lu anslutningar frn en och samma anvndare"
 #define MSG_IPV6_OK "IPv6 anslutningar r ocks vlkomna till denna server"
+#define MSG_TLS_INFO "SSL/TLS: Anvnder %s med %s, %d bitars kryptering"
+#define MSG_TLS_WEAK "SSL/TLS: Krypteringen r fr svag"
+#define MSG_TLS_NEEDED "Tyvrr r sessioner i klartext inte tilltna p denna server.\n" \
+    "Vnligen teranslut och anvnd SSL/TLS fr kad skerhet."
