@@ -2,7 +2,7 @@
 #define __QUOTAS_H__ 1
 
 #ifndef QUOTA_FILE
-# define QUOTA_FILE "/.ftpquota"
+# define QUOTA_FILE ".ftpquota"
 #endif
 
 typedef struct Quota_ {
