@@ -1,6 +1,6 @@
 #include <config.h>
 
-#if defined(WITH_UPLOAD_SCRIPT) && !defined(NON_ROOT_FTP)
+#if defined(WITH_UPLOAD_SCRIPT)
 # include "ftpd.h"
 # include "ftpwho-update.h"
 # include "globals.h"
@@ -25,18 +25,28 @@ int upload_pipe_open(void)
     }    
     if (fstat(upload_pipe_lock, &st) < 0 ||
         (st.st_mode & 0777) != 0600 || !S_ISREG(st.st_mode) ||
-        st.st_uid != (uid_t) 0) {
+# ifdef NON_ROOT_FTP
+        st.st_uid != geteuid()        
+# else
+        st.st_uid != (uid_t) 0
+# endif
+        ) {
         return -1;
     }    
     if (lstat(UPLOAD_PIPE_LOCK, &st) < 0 ||
         (st.st_mode & 0777) != 0600 || !S_ISREG(st.st_mode) ||
-        st.st_uid != (uid_t) 0) {
+# ifdef NON_ROOT_FTP
+        st.st_uid != geteuid()
+# else
+        st.st_uid != (uid_t) 0
+# endif
+        ) {
         unlink(UPLOAD_PIPE_LOCK);
         goto anew;
     }        
     anew2:
     if ((upload_pipe_fd =
-         open(UPLOAD_PIPE_FILE, O_RDWR | O_NOFOLLOW | O_NDELAY)) == -1) {
+         open(UPLOAD_PIPE_FILE, O_WRONLY | O_NOFOLLOW)) == -1) {
         if (mkfifo(UPLOAD_PIPE_FILE, (mode_t) 0600) < 0) {
             return -1;
         }
@@ -44,12 +54,22 @@ int upload_pipe_open(void)
     }
     if (fstat(upload_pipe_fd, &st) < 0 ||
         (st.st_mode & 0777) != 0600 || !S_ISFIFO(st.st_mode) ||
-        st.st_uid != (uid_t) 0) {
+# ifdef NON_ROOT_FTP
+        st.st_uid != geteuid()
+# else
+        st.st_uid != (uid_t) 0
+# endif
+        ) {
         return -1;                       /* Don't fight, I'm too old for that */
     }
     if (lstat(UPLOAD_PIPE_FILE, &st) < 0 ||
         (st.st_mode & 0777) != 0600 || !S_ISFIFO(st.st_mode) ||
-        st.st_uid != (uid_t) 0) {
+# ifdef NON_ROOT_FTP
+        st.st_uid != geteuid()
+# else
+        st.st_uid != (uid_t) 0
+# endif        
+        ) {
         unlink(UPLOAD_PIPE_FILE);       /* Okay, fight a bit :) */
         goto anew2;
     }
